# Djackal, Django Rest Framework extension

[![version badge](https://badge.fury.io/py/djackal.svg)](https://badge.fury.io/py/djackal)

![djackal image](https://imgur.com/XnlU8T9.jpg)

**Djackal** is extension of Django REST Framework(DRF)
that help you easily implement the necessary features on your web backend server.


## Warning

This repository is on developing. Some bugs may exist, possible to change suddenly. And no document yet.


## Installation

    pip install djackal
